/*
 * Asterisk -- An open source telephony toolkit.
 *
 * Copyright (C) 2005, Digium, Inc.
 *
 * Contributed by Carlos Antunes <cmantunes@gmail.com>
 * 
 * See http://www.asterisk.org for more information about
 * the Asterisk project. Please do not directly contact
 * any of the maintainers of this project for assistance;
 * the project provides a web site, mailing lists and IRC
 * channels for your use.
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 */

/*
 *
 * Sanitize phone numbers to be used on the dialplan
 * 
 */

#include <stdlib.h>
#include <string.h>
#include <sys/types.h>
#include <ctype.h>

#include "asterisk.h"

/* ASTERISK_FILE_VERSION(__FILE__, "$Revision: 1.0 $") */

#include "asterisk/channel.h"
#include "asterisk/pbx.h"
#include "asterisk/logger.h"
#include "asterisk/utils.h"
#include "asterisk/app.h"

static char *func_sanitize_phone_number(struct ast_channel *chan,
		                        char *cmd, char *data, char *buf,
					size_t len) 
{
	char *argdata;
	char *result=buf;
	char *foundopen;
	char *foundclose;
	char ch;

	/* Ensure we have data to work with */
	if (!data || ast_strlen_zero(data)) {
		ast_log(LOG_ERROR, "Syntax: SANITIZE_PHONE_NUMBER(<data>) "
				   "- missing argument!\n");
		return NULL;
	}

	/* Work with duplicate data */
	argdata=ast_strdupa(data);	

	/* Try to locate string inside brackets "<>" */
	/* Phone number lives inside these brackets, if found */
	/* If brackets not used, use the whole data as argument */
	foundopen=strchr(argdata, '<');
	if(foundopen) {
		foundclose=strrchr(foundopen, '>');
		if(foundclose) {
			/* Something inside brackets found */
			argdata=foundopen+1;
			*foundclose='\0';
		}
	}
	
	/* Sanitize argdata by removing non digits*/
	while((ch=*argdata++)!='\0' && len>1) {
		if(isdigit(ch)) {
			*result++=ch;
			--len;
		}
	}
	if(ch!='\0') {
		/* Whoops, input data too long! */
		ast_log(LOG_ERROR, "SANITIZE_PHONE_NUMBER "
				   "argument too long!\n");
		return NULL;
		
	}

	/* All is well */
	*result='\0';
	return buf;
}

#ifndef BUILTIN_FUNC
static
#endif
struct ast_custom_function sanitize_phone_number_function = {
	.name = "SANITIZE_PHONE_NUMBER",
	.synopsis = "Sanitizes a phone number unfit for the dialplan",
	.desc = "Attempts to extract a clean phone number that is suitable "
		"for use on the dialplan.\n\n"
		"Example:\n\tSanitizePhoneNumber(\"Digium\" <700-428-6000>)\n"
		"Returns:\n\t7004286000\n",
	.syntax = "SANITIZE_PHONE_NUMBER<data>)",
	.read = func_sanitize_phone_number
};
